==> haskell-glob-0.10.2-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-Km1txHXYNrY1BSEauDYVMV
key:                  Glob-0.10.2-Km1txHXYNrY1BSEauDYVMV
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  5ca211dae7365191b72b79600073a6b6
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-Km1txHXYNrY1BSEauDYVMV
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb filepath-1.4.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.2-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-FQSkuNjiRyFKcRNXpTnK7D
key:                  Glob-0.10.2-FQSkuNjiRyFKcRNXpTnK7D
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  ab9fbf71d3e449aceb2f63f4b9911ef9
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-FQSkuNjiRyFKcRNXpTnK7D
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb filepath-1.4.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
